@@ -1,9 +1,13 @@
+## File Name: BIFIE.ecdf.R
+## File Version: 0.27
+## File Last Change: 2017-10-26 15:11:11
 
 
 #######################################################################
 # empirical distribution function
 BIFIE.ecdf <- function( BIFIEobj , vars , breaks=NULL , quanttype=1 , 
-	group=NULL , group_values=NULL  ){
+	group=NULL , group_values=NULL  )
+{
 	#****
 	s1 <- Sys.time()
 	cl <- match.call()	
@@ -11,7 +15,7 @@ BIFIE.ecdf <- function( BIFIEobj , vars , breaks=NULL , quanttype=1 ,
 	if (bifieobj$cdata){
 		varnames <- unique( c( vars , group , "one") )
 		bifieobj <- BIFIE.BIFIEcdata2BIFIEdata( bifieobj , varnames=varnames )	
-						}				
+	}				
 	FF <- Nimp <- bifieobj$Nimp
 	N <- bifieobj$N
 	dat1 <- bifieobj$dat1
@@ -40,17 +44,16 @@ BIFIE.ecdf <- function( BIFIEobj , vars , breaks=NULL , quanttype=1 ,
 	if (nogroup){
 	    group <- "one"
 	    group_values <- c(1)
-			}
-			
+	}
 
 	#@@@@***
     group_index <- match( group , varnames )
 	#@@@@***
 
     if ( is.null(group_values ) ){ 
-		t1 <- fasttable( datalistM[ , group_index ] )				  
+		t1 <- bifietable( vec = datalistM[ , group_index ] )				  
 	    group_values <- sort( as.numeric( paste( names(t1) ) ))
-				}
+	}
 	
 	#@@@@***
 	res00 <- BIFIE_create_pseudogroup( datalistM , group , group_index , group_values )				
@@ -63,53 +66,46 @@ BIFIE.ecdf <- function( BIFIEobj , vars , breaks=NULL , quanttype=1 ,
 
 	if ( is.null(breaks) ){
 	    breaks <- as.numeric(seq( 0 , 1 , .01 ))
-				}
+	}
 
 	maxval <- round( max( dat1[ , vars_index ] , na.rm=TRUE ) * 100 )
 				
 	#**************************************************************************#
 	# Rcpp call
-
-	res <- bifie_ecdf( datalistM , wgt_ , wgtrep , 
-					vars_index - 1,    fayfac ,
-					Nimp , group_index - 1 , group_values , breaks , quanttype , maxval )
-
-#	res <- bifie_ecdf( datalistM , wgt_ , wgtrep , 
-#            vars_index - 1,    fayfac ,
-#            Nimp , group_index - 1 , group_values , breaks , quanttype , maxval )
-	GG <- length(group_values)
-	BB <- length(breaks)
 	
-	dfr <- as.data.frame( matrix( NA , nrow=BB , ncol=VV*GG+1 ) )
-	colnames(dfr)[1] <- "yval"
-	dfr[,1] <- breaks	
-	dfr[,-1] <- matrix( res$ecdf , nrow=BB , ncol=VV*GG )	
-	colnames(dfr)[-1] <- paste0( rep( vars , each =GG ) ,
-						"_" , group , rep( group_values , VV ) )
+	res <- bifie_ecdf( datalist=datalistM, wgt1=wgt_, wgtrep=wgtrep, vars_index=vars_index-1, 
+				fayfac=fayfac, NI=Nimp, group_index1=group_index-1, group_values=group_values, 
+				breaks=breaks, quanttype=quanttype, maxval=maxval ) 
+
+	#--- process output
+    res <- bifie_ecdf_postproc_output( res=res, group_values=group_values, breaks=breaks, 
+					VV=VV, res00=res00, vars=vars, group=group ) 
+	ecdf_ <- res$ecdf_
+	stat <- res$stat
 	
 	#@@@@***
 	# multiple groupings
-	dfr <- BIFIE_table_multiple_groupings( dfr , res00 )
-	#@@@@***
-						
+	stat <- BIFIE_table_multiple_groupings( dfr=stat, res00=res00 )
+	#@@@@***					
 	
 	#*************************** OUTPUT ***************************************
 	s2 <- Sys.time()
-	timediff <- c( s1 , s2 ) # , paste(s2-s1 ) )
-	res1 <- list( "ecdf" = dfr , "output" = res , "timediff" = timediff ,
-			"N" = N , "Nimp" = Nimp , "RR" = RR , "fayfac" = fayfac ,
-			"NMI" = BIFIEobj$NMI , "Nimp_NMI" = BIFIEobj$Nimp_NMI , 
-			"CALL"= cl )
+	timediff <- c( s1 , s2 )
+	res1 <- list( ecdf = ecdf_ , stat=stat, output = res , timediff = timediff ,
+			N = N , Nimp = Nimp , RR = RR , fayfac = fayfac ,
+			NMI = BIFIEobj$NMI , Nimp_NMI = BIFIEobj$Nimp_NMI , 			
+			CALL= cl )
 	class(res1) <- "BIFIE.ecdf"
 	return(res1)
-		}
+}
 ###################################################################################
 
 ####################################################################################
 # summary for BIFIE.ecdf function
-summary.BIFIE.ecdf <- function( object , digits=4 , ... ){
+summary.BIFIE.ecdf <- function( object , digits=4 , ... )
+{
     BIFIE.summary(object)
 	cat("Empirical Distribution Function \n")	
 	obji <- object$ecdf
 	print.object.summary( obji , digits=digits )
-			}
+}
