@@ -1,8 +1,11 @@
-
+## File Name: bifietable.R
+## File Version: 1.07
+## File Last Change: 2017-10-26 14:10:38
 
 ###########################################
 # Rcpp version of R's table function
-fasttable <- function( vec  , sort.names=FALSE ){
+bifietable <- function( vec  , sort.names=FALSE )
+{
     datavec <- matrix( vec , ncol=1 )
     # res <- bifie_fasttable( datavec )	
 	if ( storage.mode(vec) == "character" ){
@@ -28,4 +31,4 @@ fasttable <- function( vec  , sort.names=FALSE ){
         }
 ###########################################		
 
-bifietable <- fasttable
+fasttable <- bifietable 
