@@ -1,3 +1,6 @@
+## File Name: save.BIFIE.data.R
+## File Version: 1.03
+## File Last Change: 2017-01-16 13:16:43
 
 ######################################################################
 # save BIFIEdata objects
@@ -30,7 +33,7 @@ save.BIFIEdata <- function( BIFIEdata , name.BIFIEdata , cdata=TRUE , varnames=N
 				}		
 	#***********************************************************
 	#****** save objects
-    base::save( BIFIEdata , file= paste0( name.BIFIEdata , ".Rdata") )
+    save( BIFIEdata , file= paste0( name.BIFIEdata , ".Rdata") )
     sink( paste0( name.BIFIEdata , "__SUMMARY.Rout") )
 		cat( getwd() , "\n" ,
 			paste0( name.BIFIEdata , ".Rdata\n") , 
